@@ -1,4 +1,4 @@
-# Copyright (c) 2017-2022 Science and Technology Facilities Council.
+# Copyright (c) 2017-2023 Science and Technology Facilities Council.
 # Original work Copyright (c) 1999-2008 Pearu Peterson
 
 # All rights reserved.
@@ -65,14 +65,39 @@
 # First version by: Pearu Peterson <pearu@cens.ioc.ee>
 # First created: Oct 2006
 
+try:
+    from importlib.metadata import PackageNotFoundError
+    from importlib import metadata
+except ImportError:
+    # Use backport package for python <3.8
+    from importlib_metadata import PackageNotFoundError
+    import importlib_metadata as metadata
+
 import logging
 import codecs
 
+
+def _get_version():
+    """
+    :returns: the version of this package.
+    :rtype: str
+    """
+    try:
+        return metadata.version(__name__)
+    except PackageNotFoundError:
+        # Package is not installed.
+        from setuptools_scm import get_version
+
+        return get_version(root="../..", relative_to=__file__)
+
+
+__version__ = _get_version()
+
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
 
 def log_decode_error_handler(err):
-    '''
+    """
     A custom error handler for use when reading files. Removes any
     characters that cause decoding errors and logs the error.
 
@@ -80,7 +105,7 @@ def log_decode_error_handler(err):
               and the position from where encoding should continue.
     :rtype: Tuple[str, int]
 
-    '''
+    """
     message = f"character in input file. Error returned was {str(err)}."
     # Log the fact that this character will be removed from the input file
     logging.getLogger(__name__).warning("Skipped bad %s", message)
