@@ -74,44 +74,90 @@ Test parsing single Fortran lines.
 
 import pytest
 
-from fparser.common.splitline import splitparen, splitquote, \
-    string_replace_map, StringReplaceDict
+from fparser.common.splitline import (
+    splitparen,
+    splitquote,
+    string_replace_map,
+    StringReplaceDict,
+)
 
 
 def test_splitparen():
-    ''' Unit tests for splitparen function.'''
-    assert splitparen('abc') == ['abc']
-    assert splitparen('abc(1)') == ['abc', '(1)']
-    assert splitparen('abc(1) xyz') == ['abc', '(1)', ' xyz']
-    assert splitparen('a(b) = b(x,y(1)) b((a))') == \
-        ['a', '(b)', ' = b', '(x,y(1))', ' b', '((a))']
+    """Unit tests for splitparen function."""
+    assert splitparen("abc") == ["abc"]
+    assert splitparen("abc(1)") == ["abc", "(1)"]
+    assert splitparen("abc(1) xyz") == ["abc", "(1)", " xyz"]
+    assert splitparen("a(b) = b(x,y(1)) b((a))") == [
+        "a",
+        "(b)",
+        " = b",
+        "(x,y(1))",
+        " b",
+        "((a))",
+    ]
     # pylint: disable=anomalous-backslash-in-string
-    assert splitparen(r'a(b) = b(x,y(1)) b\((a)\)') == \
-        ['a', '(b)', ' = b', '(x,y(1))', ' b\\(', '(a)', '\\)']
+    assert splitparen(r"a(b) = b(x,y(1)) b\((a)\)") == [
+        "a",
+        "(b)",
+        " = b",
+        "(x,y(1))",
+        " b\\(",
+        "(a)",
+        "\\)",
+    ]
     # pylint: enable=anomalous-backslash-in-string
-    assert splitparen('abc[1]') == ['abc', '[1]']
-    assert splitparen('abc[1,2,3]') == ['abc', '[1,2,3]']
-    assert splitparen('a[b] = b[x,y(1)] b((a))') == \
-        ['a', '[b]', ' = b', '[x,y(1)]', ' b', '((a))']
+    assert splitparen("abc[1]") == ["abc", "[1]"]
+    assert splitparen("abc[1,2,3]") == ["abc", "[1,2,3]"]
+    assert splitparen("a[b] = b[x,y(1)] b((a))") == [
+        "a",
+        "[b]",
+        " = b",
+        "[x,y(1)]",
+        " b",
+        "((a))",
+    ]
     # pylint: disable=anomalous-backslash-in-string
-    assert splitparen(r'a[b] = b[x,y(1)] b\((a)\)') == \
-        ['a', '[b]', ' = b', '[x,y(1)]', ' b\\(', '(a)', '\\)']
+    assert splitparen(r"a[b] = b[x,y(1)] b\((a)\)") == [
+        "a",
+        "[b]",
+        " = b",
+        "[x,y(1)]",
+        " b\\(",
+        "(a)",
+        "\\)",
+    ]
     # pylint: enable=anomalous-backslash-in-string
-    assert splitparen('integer a(3) = (/"a", "b", "c"/)') == \
-        ['integer a', '(3)', ' = ', '(/"a", "b", "c"/)']
-    assert splitparen(
-        'character(len=40) :: a(3) = (/"a[),", ",b,[(", "c,][)("/)') == \
-        ['character', '(len=40)', ' :: a', '(3)', ' = ',
-         '(/"a[),", ",b,[(", "c,][)("/)']
-    assert splitparen('integer a(3) = ["a", "b", "c"]') == \
-        ['integer a', '(3)', ' = ', '["a", "b", "c"]']
-    assert splitparen(
-        'character(len=40) :: a(3) = ["a[),", ",b,[(", "c,][)("]') == \
-        ['character', '(len=40)', ' :: a', '(3)', ' = ',
-         '["a[),", ",b,[(", "c,][)("]']
+    assert splitparen('integer a(3) = (/"a", "b", "c"/)') == [
+        "integer a",
+        "(3)",
+        " = ",
+        '(/"a", "b", "c"/)',
+    ]
+    assert splitparen('character(len=40) :: a(3) = (/"a[),", ",b,[(", "c,][)("/)') == [
+        "character",
+        "(len=40)",
+        " :: a",
+        "(3)",
+        " = ",
+        '(/"a[),", ",b,[(", "c,][)("/)',
+    ]
+    assert splitparen('integer a(3) = ["a", "b", "c"]') == [
+        "integer a",
+        "(3)",
+        " = ",
+        '["a", "b", "c"]',
+    ]
+    assert splitparen('character(len=40) :: a(3) = ["a[),", ",b,[(", "c,][)("]') == [
+        "character",
+        "(len=40)",
+        " :: a",
+        "(3)",
+        " = ",
+        '["a[),", ",b,[(", "c,][)("]',
+    ]
     # pylint: disable=anomalous-backslash-in-string
     result = splitparen('a(1),b\\((2,3),c\\\\((1)),c"("')
-    expected = ['a', '(1)', ',b\\(', '(2,3)', ',c\\\\', '((1))', ',c"("']
+    expected = ["a", "(1)", ",b\\(", "(2,3)", ",c\\\\", "((1))", ',c"("']
     # pylint: enable=anomalous-backslash-in-string
     assert result == expected
     # Useful for debugging:
@@ -120,67 +166,99 @@ def test_splitparen():
 
 
 def test_splitquote():
-    '''Tests splitquote function.'''
+    """Tests splitquote function."""
     split_list, stopchar = splitquote('abc\\\' def"12\\"3""56"dfad\'a d\'')
-    assert split_list == ['abc\\\' def', '"12\\"3"', '"56"', 'dfad', '\'a d\'']
+    assert split_list == ["abc\\' def", '"12\\"3"', '"56"', "dfad", "'a d'"]
     assert stopchar is None
     result, stopchar = splitquote('abc\\\' def"12\\"3""56"dfad\'a d\'')
-    assert result == ['abc\\\' def', '"12\\"3"', '"56"', 'dfad', '\'a d\'']
+    assert result == ["abc\\' def", '"12\\"3"', '"56"', "dfad", "'a d'"]
     assert stopchar is None
 
-    split_list, stopchar = splitquote('a\'')
-    assert split_list == ['a', '\'']
-    assert stopchar == '\''
+    split_list, stopchar = splitquote("a'")
+    assert split_list == ["a", "'"]
+    assert stopchar == "'"
 
-    split_list, stopchar = splitquote('a\'b')
-    assert split_list == ['a', '\'b']
-    assert stopchar == '\''
+    split_list, stopchar = splitquote("a'b")
+    assert split_list == ["a", "'b"]
+    assert stopchar == "'"
 
 
 @pytest.mark.parametrize(
     "test_str, result, result_map",
-    [("a()", "a()", {}),
-     ("a(b + c)", "a(F2PY_EXPR_TUPLE_1)", {"F2PY_EXPR_TUPLE_1": "b + c"}),
-     ("0.5d0*a", "F2PY_REAL_CONSTANT_1_*a",
-      {"F2PY_REAL_CONSTANT_1_": "0.5d0"}),
-     (".5d0*a", "F2PY_REAL_CONSTANT_1_*a", {"F2PY_REAL_CONSTANT_1_": ".5d0"}),
-     ("a + 1.0e-10*c", "a + F2PY_REAL_CONSTANT_1_*c",
-      {"F2PY_REAL_CONSTANT_1_": "1.0e-10"}),
-     ("a + 1.0e-10*c + 1.0e-10*d",
-      "a + F2PY_REAL_CONSTANT_1_*c + F2PY_REAL_CONSTANT_1_*d",
-      {"F2PY_REAL_CONSTANT_1_": "1.0e-10"}),
-     ("a + 1.0E-10*c + 1.0e-11*d", "a + F2PY_REAL_CONSTANT_1_*c + "
-      "F2PY_REAL_CONSTANT_2_*d", {"F2PY_REAL_CONSTANT_1_": "1.0E-10",
-                                  "F2PY_REAL_CONSTANT_2_": "1.0e-11"}),
-     ("a1e-3*1e3", "a1e-3*F2PY_REAL_CONSTANT_1_", {"F2PY_REAL_CONSTANT_1_":
-                                                   "1e3"}),
-     ("3.0 - .32D+3", "3.0 - F2PY_REAL_CONSTANT_1_",
-      {"F2PY_REAL_CONSTANT_1_": ".32D+3"}),
-     ("var=1.0d-3", "var=F2PY_REAL_CONSTANT_1_",
-      {"F2PY_REAL_CONSTANT_1_": "1.0d-3"}),
-     (".5e3_wp*a", "F2PY_REAL_CONSTANT_1_*a",
-      {"F2PY_REAL_CONSTANT_1_": ".5e3_wp"}),
-     ("5.e+3_wp*a", "F2PY_REAL_CONSTANT_1_*a",
-      {"F2PY_REAL_CONSTANT_1_": "5.e+3_wp"}),
-     ("IF(ABS( zds) <= 1.e-20_wp)   zds = 1.e-20_wp",
-      "IF(F2PY_EXPR_TUPLE_1)   zds = F2PY_REAL_CONSTANT_1_",
-      {"F2PY_EXPR_TUPLE_1": "ABS( zds) <= 1.e-20_wp",
-       "F2PY_REAL_CONSTANT_1_": "1.e-20_wp"}),
-     ("1.e-1+2.e-1+3.e-1+4.e-1+5.e-1+6.e-1+7.e-1+8.e-1+9.e-1+1.1e-1+1.2e-2",
-      "F2PY_REAL_CONSTANT_1_+F2PY_REAL_CONSTANT_2_+F2PY_REAL_CONSTANT_3_+"
-      "F2PY_REAL_CONSTANT_4_+F2PY_REAL_CONSTANT_5_+F2PY_REAL_CONSTANT_6_+"
-      "F2PY_REAL_CONSTANT_7_+F2PY_REAL_CONSTANT_8_+F2PY_REAL_CONSTANT_9_+"
-      "F2PY_REAL_CONSTANT_10_+F2PY_REAL_CONSTANT_11_",
-      {"F2PY_REAL_CONSTANT_1_": "1.e-1", "F2PY_REAL_CONSTANT_2_": "2.e-1",
-       "F2PY_REAL_CONSTANT_3_": "3.e-1", "F2PY_REAL_CONSTANT_4_": "4.e-1",
-       "F2PY_REAL_CONSTANT_5_": "5.e-1", "F2PY_REAL_CONSTANT_6_": "6.e-1",
-       "F2PY_REAL_CONSTANT_7_": "7.e-1", "F2PY_REAL_CONSTANT_8_": "8.e-1",
-       "F2PY_REAL_CONSTANT_9_": "9.e-1", "F2PY_REAL_CONSTANT_10_": "1.1e-1",
-       "F2PY_REAL_CONSTANT_11_": "1.2e-2"}),
-     ("'value = 1.0d-3'", "'_F2PY_STRING_CONSTANT_1_'",
-      {"_F2PY_STRING_CONSTANT_1_": "value = 1.0d-3"})])
+    [
+        ("a()", "a()", {}),
+        ("a(b + c)", "a(F2PY_EXPR_TUPLE_1)", {"F2PY_EXPR_TUPLE_1": "b + c"}),
+        ("0.5d0*a", "F2PY_REAL_CONSTANT_1_*a", {"F2PY_REAL_CONSTANT_1_": "0.5d0"}),
+        (".5d0*a", "F2PY_REAL_CONSTANT_1_*a", {"F2PY_REAL_CONSTANT_1_": ".5d0"}),
+        (
+            "a + 1.0e-10*c",
+            "a + F2PY_REAL_CONSTANT_1_*c",
+            {"F2PY_REAL_CONSTANT_1_": "1.0e-10"},
+        ),
+        (
+            "a + 1.0e-10*c + 1.0e-10*d",
+            "a + F2PY_REAL_CONSTANT_1_*c + F2PY_REAL_CONSTANT_1_*d",
+            {"F2PY_REAL_CONSTANT_1_": "1.0e-10"},
+        ),
+        (
+            "a + 1.0E-10*c + 1.0e-11*d",
+            "a + F2PY_REAL_CONSTANT_1_*c + " "F2PY_REAL_CONSTANT_2_*d",
+            {"F2PY_REAL_CONSTANT_1_": "1.0E-10", "F2PY_REAL_CONSTANT_2_": "1.0e-11"},
+        ),
+        ("a1e-3*1e3", "a1e-3*F2PY_REAL_CONSTANT_1_", {"F2PY_REAL_CONSTANT_1_": "1e3"}),
+        (
+            "3.0 - .32D+3",
+            "3.0 - F2PY_REAL_CONSTANT_1_",
+            {"F2PY_REAL_CONSTANT_1_": ".32D+3"},
+        ),
+        (
+            "var=1.0d-3",
+            "var=F2PY_REAL_CONSTANT_1_",
+            {"F2PY_REAL_CONSTANT_1_": "1.0d-3"},
+        ),
+        (".5e3_wp*a", "F2PY_REAL_CONSTANT_1_*a", {"F2PY_REAL_CONSTANT_1_": ".5e3_wp"}),
+        (
+            "5.e+3_wp*a",
+            "F2PY_REAL_CONSTANT_1_*a",
+            {"F2PY_REAL_CONSTANT_1_": "5.e+3_wp"},
+        ),
+        (
+            "IF(ABS( zds) <= 1.e-20_wp)   zds = 1.e-20_wp",
+            "IF(F2PY_EXPR_TUPLE_1)   zds = F2PY_REAL_CONSTANT_1_",
+            {
+                "F2PY_EXPR_TUPLE_1": "ABS( zds) <= 1.e-20_wp",
+                "F2PY_REAL_CONSTANT_1_": "1.e-20_wp",
+            },
+        ),
+        (
+            "1.e-1+2.e-1+3.e-1+4.e-1+5.e-1+6.e-1+7.e-1+8.e-1+9.e-1+1.1e-1+1.2e-2",
+            "F2PY_REAL_CONSTANT_1_+F2PY_REAL_CONSTANT_2_+F2PY_REAL_CONSTANT_3_+"
+            "F2PY_REAL_CONSTANT_4_+F2PY_REAL_CONSTANT_5_+F2PY_REAL_CONSTANT_6_+"
+            "F2PY_REAL_CONSTANT_7_+F2PY_REAL_CONSTANT_8_+F2PY_REAL_CONSTANT_9_+"
+            "F2PY_REAL_CONSTANT_10_+F2PY_REAL_CONSTANT_11_",
+            {
+                "F2PY_REAL_CONSTANT_1_": "1.e-1",
+                "F2PY_REAL_CONSTANT_2_": "2.e-1",
+                "F2PY_REAL_CONSTANT_3_": "3.e-1",
+                "F2PY_REAL_CONSTANT_4_": "4.e-1",
+                "F2PY_REAL_CONSTANT_5_": "5.e-1",
+                "F2PY_REAL_CONSTANT_6_": "6.e-1",
+                "F2PY_REAL_CONSTANT_7_": "7.e-1",
+                "F2PY_REAL_CONSTANT_8_": "8.e-1",
+                "F2PY_REAL_CONSTANT_9_": "9.e-1",
+                "F2PY_REAL_CONSTANT_10_": "1.1e-1",
+                "F2PY_REAL_CONSTANT_11_": "1.2e-2",
+            },
+        ),
+        (
+            "'value = 1.0d-3'",
+            "'_F2PY_STRING_CONSTANT_1_'",
+            {"_F2PY_STRING_CONSTANT_1_": "value = 1.0d-3"},
+        ),
+    ],
+)
 def test_string_replace_map(test_str, result, result_map):
-    '''Tests string_replace_map function for various expressions.'''
+    """Tests string_replace_map function for various expressions."""
     string, string_map = string_replace_map(test_str)
     assert string == result
     assert string_map == result_map
@@ -188,7 +266,7 @@ def test_string_replace_map(test_str, result, result_map):
 
 
 def test_string_replace_dict():
-    ''' Tests for the StringReplaceDict class. '''
+    """Tests for the StringReplaceDict class."""
     repmap = StringReplaceDict()
     assert repmap == {}
     repmap["F2PY_REAL_CONSTANT_1_"] = "a_value"
