@@ -33,9 +33,9 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-''' pytest module for the Fortran2003 Case Construct - R808.
+""" pytest module for the Fortran2003 Case Construct - R808.
     Does not test all aspects of R808, in particular the conditions C803-7
-    are not checked - #232. '''
+    are not checked - #232. """
 
 import pytest
 from fparser.api import get_reader
@@ -46,9 +46,11 @@ from fparser.two.utils import FortranSyntaxError
 
 @pytest.mark.usefixtures("f2003_create")
 def test_case_construct():
-    ''' Basic test that we parse a Case Construct successfully. '''
+    """Basic test that we parse a Case Construct successfully."""
     tcls = Case_Construct
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 select case (n)
 case (:-1)
   signum = -1
@@ -59,18 +61,23 @@ case (1:)
 case default
   signum = -2
 end select
-'''))
+"""
+        )
+    )
     assert isinstance(obj, tcls), repr(obj)
-    assert (str(obj) ==
-            'SELECT CASE (n)\nCASE (: - 1)\n  signum = - 1\nCASE (0)\n'
-            '  signum = 0\nCASE (1 :)\n  signum = 1\nCASE DEFAULT\n'
-            '  signum = - 2\nEND SELECT')
+    assert (
+        str(obj) == "SELECT CASE (n)\nCASE (: - 1)\n  signum = - 1\nCASE (0)\n"
+        "  signum = 0\nCASE (1 :)\n  signum = 1\nCASE DEFAULT\n"
+        "  signum = - 2\nEND SELECT"
+    )
 
 
 def test_case_construct_name(f2003_create):
-    ''' Basic test that we parse a Case Construct successfully. '''
+    """Basic test that we parse a Case Construct successfully."""
     tcls = Case_Construct
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
     name: select case (n)
     case (:-1) name
         signum = -1
@@ -81,22 +88,28 @@ def test_case_construct_name(f2003_create):
     case default name
         signum = -2
     end select name
-    '''))
+    """
+        )
+    )
     assert isinstance(obj, tcls), repr(obj)
-    assert (str(obj) ==
-            'name:SELECT CASE (n)\nCASE (: - 1) name\n  signum = - 1\nCASE (0) name\n'
-            '  signum = 0\nCASE (1 :) name\n  signum = 1\nCASE DEFAULT name\n'
-            '  signum = - 2\nEND SELECT name')
+    assert (
+        str(obj)
+        == "name:SELECT CASE (n)\nCASE (: - 1) name\n  signum = - 1\nCASE (0) name\n"
+        "  signum = 0\nCASE (1 :) name\n  signum = 1\nCASE DEFAULT name\n"
+        "  signum = - 2\nEND SELECT name"
+    )
 
 
 @pytest.mark.usefixtures("f2003_create")
 def test_tofortran_non_ascii():
-    ''' Check that the tofortran() method works when the character string
-    contains non-ascii characters. '''
-    code = (u"SELECT CASE(iflag)\n"
-            u"CASE(  30  ) ! This is a comment\n"
-            u"  IF(lwp) WRITE(*,*) ' for e1=1\xb0'\n"
-            u"END SELECT\n")
+    """Check that the tofortran() method works when the character string
+    contains non-ascii characters."""
+    code = (
+        "SELECT CASE(iflag)\n"
+        "CASE(  30  ) ! This is a comment\n"
+        "  IF(lwp) WRITE(*,*) ' for e1=1\xb0'\n"
+        "END SELECT\n"
+    )
     reader = FortranStringReader(code, ignore_comments=False)
     obj = Case_Construct(reader)
     out_str = str(obj)
@@ -107,11 +120,14 @@ def test_case_construct_wrong_name(f2003_create, fake_symbol_table):
     """Check that named 'case' block has correct matching start/end name"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         Case_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: select case (n)
             case (:-1)
                 a = 1
-            end select wrong"""))
+            end select wrong"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name', got 'wrong'")
 
 
@@ -119,23 +135,31 @@ def test_case_construct_missing_start_name(f2003_create, fake_symbol_table):
     """Check that named 'case' block has correct matching start/end name"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         Case_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             select case(n)
             case (:-1)
                 a = 1
-            end select name"""))
-    assert exc_info.value.args[0].endswith("Name 'name' has no corresponding starting name")
+            end select name"""
+            )
+        )
+    assert exc_info.value.args[0].endswith(
+        "Name 'name' has no corresponding starting name"
+    )
 
 
 def test_case_construct_missing_end_name(f2003_create, fake_symbol_table):
     """Check that named 'case' block has correct matching start/end name"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         Case_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: select case(n)
             case (:-1)
                 a = 1
-            end select"""))
+            end select"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name' but none given")
 
 
@@ -143,9 +167,12 @@ def test_case_construct_case_wrong_name(f2003_create, fake_symbol_table):
     """Check that named 'case' block has correct matching start/end name"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         Case_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: select case(n)
             case (:-1) wrong
                 a = 1
-            end select name"""))
+            end select name"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name', got 'wrong'")
