@@ -33,9 +33,9 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-''' pytest module for the Fortran2003 If Construct - R802. Note that
+""" pytest module for the Fortran2003 If Construct - R802. Note that
     this requires re-implementing and extending to fully cover the
-    language specification (#232). '''
+    language specification (#232). """
 
 import pytest
 from fparser.api import get_reader
@@ -46,25 +46,35 @@ from fparser.two.utils import FortranSyntaxError
 
 @pytest.mark.usefixtures("f2003_create", "fake_symbol_table")
 def test_if_construct():
-    ''' Basic tests for the if construct. '''
+    """Basic tests for the if construct."""
     tcls = If_Construct
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 if (expr) then
   a = 1
 end if
-    '''))
+    """
+        )
+    )
     assert isinstance(obj, tcls), repr(obj)
-    assert str(obj) == 'IF (expr) THEN\n  a = 1\nEND IF'
+    assert str(obj) == "IF (expr) THEN\n  a = 1\nEND IF"
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 name: if (expr) then
   a = 1
 end if name
-    '''))
+    """
+        )
+    )
 
-    assert str(obj) == 'name:IF (expr) THEN\n  a = 1\nEND IF name'
+    assert str(obj) == "name:IF (expr) THEN\n  a = 1\nEND IF name"
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 if (expr) then
   a = 1
   if (expr2) then
@@ -72,33 +82,45 @@ if (expr) then
   endif
   a = 3
 end if
-    '''))
+    """
+        )
+    )
     assert isinstance(obj, tcls), repr(obj)
-    assert (str(obj) ==
-            'IF (expr) THEN\n  a = 1\n  IF (expr2) THEN\n    a = 2\n'
-            '  END IF\n  a = 3\nEND IF')
+    assert (
+        str(obj) == "IF (expr) THEN\n  a = 1\n  IF (expr2) THEN\n    a = 2\n"
+        "  END IF\n  a = 3\nEND IF"
+    )
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 if (expr) then
   a = 1
 else if (expr2) then
   a = 2
 end if
-    '''))
+    """
+        )
+    )
     assert isinstance(obj, tcls), repr(obj)
-    assert (str(obj) ==
-            'IF (expr) THEN\n  a = 1\nELSE IF (expr2) THEN\n  a = 2\nEND IF')
+    assert str(obj) == "IF (expr) THEN\n  a = 1\nELSE IF (expr2) THEN\n  a = 2\nEND IF"
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 if (expr) then
   a = 1
 else
   a = 2
 end if
-    '''))
-    assert str(obj) == 'IF (expr) THEN\n  a = 1\nELSE\n  a = 2\nEND IF'
+    """
+        )
+    )
+    assert str(obj) == "IF (expr) THEN\n  a = 1\nELSE\n  a = 2\nEND IF"
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 if (expr) then
   a = 1
 else if (expr2) then
@@ -106,34 +128,49 @@ else if (expr2) then
 else
   a = 3
 end if
-    '''))
-    assert (str(obj) ==
-            'IF (expr) THEN\n  a = 1\nELSE IF (expr2) THEN\n  a = 2\n'
-            'ELSE\n  a = 3\nEND IF')
+    """
+        )
+    )
+    assert (
+        str(obj) == "IF (expr) THEN\n  a = 1\nELSE IF (expr2) THEN\n  a = 2\n"
+        "ELSE\n  a = 3\nEND IF"
+    )
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 named: if (expr) then
   a = 1
 else named
   a = 2
 end if named
-    '''))
-    assert (str(obj) ==
-            'named:IF (expr) THEN\n  a = 1\nELSE named\n  a = 2\nEND IF named')
+    """
+        )
+    )
+    assert (
+        str(obj) == "named:IF (expr) THEN\n  a = 1\nELSE named\n  a = 2\nEND IF named"
+    )
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 named: if (expr) then
   a = 1
   named2: if (expr2) then
     a = 2
   end if named2
 end if named
-'''))
-    assert (str(obj) ==
-            'named:IF (expr) THEN\n  a = 1\n  named2:IF (expr2) THEN\n'
-            '    a = 2\n  END IF named2\nEND IF named')
+"""
+        )
+    )
+    assert (
+        str(obj) == "named:IF (expr) THEN\n  a = 1\n  named2:IF (expr2) THEN\n"
+        "    a = 2\n  END IF named2\nEND IF named"
+    )
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
 if (expr) then
   a = 1
 else if (expr2) then
@@ -141,13 +178,18 @@ else if (expr2) then
 else if (expr3) then
   a = 3
 end if
-    '''))
+    """
+        )
+    )
     assert isinstance(obj, tcls), repr(obj)
-    assert (str(obj) ==
-            'IF (expr) THEN\n  a = 1\nELSE IF (expr2) THEN\n  a = 2\n'
-            'ELSE IF (expr3) THEN\n  a = 3\nEND IF')
+    assert (
+        str(obj) == "IF (expr) THEN\n  a = 1\nELSE IF (expr2) THEN\n  a = 2\n"
+        "ELSE IF (expr3) THEN\n  a = 3\nEND IF"
+    )
 
-    obj = tcls(get_reader('''\
+    obj = tcls(
+        get_reader(
+            """\
         if (dxmx .gt. 0d0) then
           diff = 0
           do  80  k = 1, n
@@ -162,17 +204,17 @@ end if
             do  82  k = 1, n
    82       xnew(k) = xin(k) + betx*(xnew(k)-xin(k))
           endif
-        endif'''))
+        endif"""
+        )
+    )
     assert isinstance(obj, tcls)
 
 
 @pytest.mark.usefixtures("f2003_create")
 def test_ifconstruct_tofortran_non_ascii():
-    ''' Check that the tofortran() method works when the if-construct contains
-    a character string with non-ascii characters. '''
-    code = (u"IF(iflag)THEN\n"
-            u"  WRITE(*,*) ' for e1=1\xb0'\n"
-            u"END IF\n")
+    """Check that the tofortran() method works when the if-construct contains
+    a character string with non-ascii characters."""
+    code = "IF(iflag)THEN\n" "  WRITE(*,*) ' for e1=1\xb0'\n" "END IF\n"
     reader = FortranStringReader(code, ignore_comments=False)
     obj = If_Construct(reader)
     out_str = str(obj)
@@ -183,10 +225,13 @@ def test_if_construct_wrong_name(f2003_create, fake_symbol_table):
     """Check named 'if' constructs have correct start/end names"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         If_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: if (expr) then
                 a = 1
-            end if wrong"""))
+            end if wrong"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name', got 'wrong'")
 
 
@@ -194,21 +239,29 @@ def test_if_construct_missing_start_name(f2003_create, fake_symbol_table):
     """Check named 'if' constructs have correct start/end names"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         If_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             if (expr) then
                 a = 1
-            end if name"""))
-    assert exc_info.value.args[0].endswith("Name 'name' has no corresponding starting name")
+            end if name"""
+            )
+        )
+    assert exc_info.value.args[0].endswith(
+        "Name 'name' has no corresponding starting name"
+    )
 
 
 def test_if_construct_missing_end_name(f2003_create, fake_symbol_table):
     """Check named 'if' constructs have correct start/end names"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         If_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: if (expr) then
                 a = 1
-            end if"""))
+            end if"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name' but none given")
 
 
@@ -216,12 +269,15 @@ def test_if_construct_else_wrong_end_name(f2003_create, fake_symbol_table):
     """Check named 'if' constructs have correct start/end names"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         If_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: if (expr) then
                 a = 1
             else
                 a = 2
-            end if wrong"""))
+            end if wrong"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name', got 'wrong'")
 
 
@@ -229,12 +285,15 @@ def test_if_construct_else_wrong_name(f2003_create, fake_symbol_table):
     """Check named 'if' constructs have correct start/end names"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         If_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: if (expr) then
                 a = 1
             else wrong
                 a = 2
-            end if name"""))
+            end if name"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name', got 'wrong'")
 
 
@@ -242,10 +301,13 @@ def test_if_construct_else_if_wrong_name(f2003_create, fake_symbol_table):
     """Check named 'if' constructs have correct start/end names"""
     with pytest.raises(FortranSyntaxError) as exc_info:
         If_Construct(
-            get_reader("""\
+            get_reader(
+                """\
             name: if (expr) then
                 a = 1
             else if (other_expr) then wrong
                 a = 2
-            end if name"""))
+            end if name"""
+            )
+        )
     assert exc_info.value.args[0].endswith("Expecting name 'name', got 'wrong'")
