@@ -32,65 +32,65 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-'''Test Fortran 2008 rule R1119.
+"""Test Fortran 2008 rule R1119.
 
     end-submodule-stmt is END [ SUBMODULE [ submodule-name ] ]
 
-'''
+"""
 import pytest
 from fparser.two.utils import NoMatchError
 from fparser.two.Fortran2008 import End_Submodule_Stmt
 
 
 def test_simple_1(f2008_create):
-    '''Test the parsing of a minimal end-submodule statement.'''
+    """Test the parsing of a minimal end-submodule statement."""
     result = End_Submodule_Stmt("end")
     assert str(result) == "END"
 
 
 def test_simple_2(f2008_create):
-    '''Test the parsing of an end-submodule statement which includes the
+    """Test the parsing of an end-submodule statement which includes the
     submodule keyword.
 
-    '''
+    """
     result = End_Submodule_Stmt("end submodule")
     assert str(result) == "END SUBMODULE"
 
 
 def test_simple_3(f2008_create):
-    '''Test the parsing of an end-submodule statement which includes the
+    """Test the parsing of an end-submodule statement which includes the
     submodule name
 
-    '''
+    """
     result = End_Submodule_Stmt("end submodule name")
     assert str(result) == "END SUBMODULE name"
 
 
 def test_simple_error1(f2008_create):
-    '''Test an end-submodule statement with a syntax error raises an
+    """Test an end-submodule statement with a syntax error raises an
     exception.
 
-    '''
+    """
     with pytest.raises(NoMatchError) as excinfo:
         dummy_ = End_Submodule_Stmt("edn")
     assert "End_Submodule_Stmt: 'edn'" in str(excinfo.value)
 
 
 def test_simple_error2(f2008_create):
-    '''Test an end-submodule statement with a syntax error raises an
+    """Test an end-submodule statement with a syntax error raises an
     exception.
 
-    '''
+    """
     with pytest.raises(NoMatchError) as excinfo:
         dummy_ = End_Submodule_Stmt("end submod")
     assert "End_Submodule_Stmt: 'end submod'" in str(excinfo.value)
 
 
 def test_simple_error3(f2008_create):
-    '''Test an end-submodule statement with additional content after the
+    """Test an end-submodule statement with additional content after the
     match raises an exception.
 
-    '''
+    """
     with pytest.raises(NoMatchError) as excinfo:
         dummy_ = End_Submodule_Stmt("end submodule name :")
     assert "End_Submodule_Stmt: 'end submodule name :'" in str(excinfo.value)
