@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2020 Science and Technology Facilities Council
+# Copyright (c) 2018-2023 Science and Technology Facilities Council.
 
 # All rights reserved.
 
@@ -32,81 +32,112 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-'''Test utils.py which contain base classes to support fparser,
+"""Test utils.py which contains base classes to support fparser,
 exception handling and ast traversal.
 
-'''
+"""
 
 import pytest
-from fparser.two.utils import FortranSyntaxError
 from fparser.api import get_reader
+from fparser.two import Fortran2003, utils
+
 
 # test BlockBase
 
 
-def test_blockbase_match_names(f2003_create):
-    '''Test the blockbase name matching option in its match method. We use
+@pytest.mark.usefixtures("f2003_create")
+def test_blockbase_match_names():
+    """Test the blockbase name matching option in its match method. We use
     the Derived_Type_Def class (which subclasses BlockBase) for this
     as it sets match_names to True.
 
-    '''
-    from fparser.two.Fortran2003 import Derived_Type_Def, Case_Construct
-
+    """
     # working named example
     reader = get_reader("type abc\nend type abc")
-    ast = Derived_Type_Def(reader)
+    ast = Fortran2003.Derived_Type_Def(reader)
     assert "TYPE :: abc\nEND TYPE abc" in str(ast)
 
     # case insensitive
     reader = get_reader("type abc\nend type ABC")
-    ast = Derived_Type_Def(reader)
+    ast = Fortran2003.Derived_Type_Def(reader)
     assert "TYPE :: abc\nEND TYPE ABC" in str(ast)
 
     # incorrect name exception
     reader = get_reader("type abc\nend type cde")
-    with pytest.raises(FortranSyntaxError) as excinfo:
-        ast = Derived_Type_Def(reader)
-    assert "at line 2\n>>>end type cde\nExpecting name 'abc'" \
-        in str(excinfo.value)
+    with pytest.raises(utils.FortranSyntaxError) as excinfo:
+        ast = Fortran2003.Derived_Type_Def(reader)
+    assert "at line 2\n>>>end type cde\nExpecting name 'abc'" in str(excinfo.value)
 
     # first name required if second name supplied
     # switch to using select case as it can trip the exception
     reader = get_reader("select case (i)\nend select label")
-    with pytest.raises(FortranSyntaxError) as excinfo:
-        ast = Case_Construct(reader)
-    assert ("at line 2\n>>>end select label\nName 'label' has no "
-            "corresponding starting name") in str(excinfo.value)
+    with pytest.raises(utils.FortranSyntaxError) as excinfo:
+        ast = Fortran2003.Case_Construct(reader)
+    assert (
+        "at line 2\n>>>end select label\nName 'label' has no "
+        "corresponding starting name"
+    ) in str(excinfo.value)
 
 
-def test_blockbase_match_name_classes(f2003_create):
-    '''Test the blockbase name matching option in its match method. We use
+@pytest.mark.usefixtures("f2003_create")
+def test_blockbase_match_name_classes():
+    """Test the blockbase name matching option in its match method. We use
     the If_Construct class (which subclasses BlockBase) for this as it
     sets match_names to True and provides match_name_classes. This is
     used when names can appear in multiple places.
 
-    '''
-    from fparser.two.Fortran2003 import If_Construct
-
+    """
     # working named example
     reader = get_reader("label:if (.true.) then\nendif label")
-    ast = If_Construct(reader)
+    ast = Fortran2003.If_Construct(reader)
     assert "label:IF (.TRUE.) THEN\nEND IF label" in str(ast)
 
     # case insensitive
     reader = get_reader("label:if (.true.) then\nendif LABEL")
-    ast = If_Construct(reader)
+    ast = Fortran2003.If_Construct(reader)
     assert "label:IF (.TRUE.) THEN\nEND IF LABEL" in str(ast)
 
     # incorrect name exception
     reader = get_reader("label:if (.true.) then\nendif bella")
-    with pytest.raises(FortranSyntaxError) as excinfo:
-        ast = If_Construct(reader)
-    assert "at line 2\n>>>endif bella\nExpecting name 'label'" \
-        in str(excinfo.value)
+    with pytest.raises(utils.FortranSyntaxError) as excinfo:
+        ast = Fortran2003.If_Construct(reader)
+    assert "at line 2\n>>>endif bella\nExpecting name 'label'" in str(excinfo.value)
 
     # first name required if subsequent name supplied
     reader = get_reader("if (.true.) then\nendif label")
-    with pytest.raises(FortranSyntaxError) as excinfo:
-        ast = If_Construct(reader)
-    assert ("at line 2\n>>>endif label\nName 'label' has no corresponding "
-            "starting name") in str(excinfo.value)
+    with pytest.raises(utils.FortranSyntaxError) as excinfo:
+        ast = Fortran2003.If_Construct(reader)
+    assert (
+        "at line 2\n>>>endif label\nName 'label' has no corresponding " "starting name"
+    ) in str(excinfo.value)
+
+
+@pytest.mark.usefixtures("f2003_create")
+def test_endstmtbase_match():
+    """Tests for the EndStmtBase.match() method."""
+    result = utils.EndStmtBase.match("critical", None, "hello")
+    assert result is None
+    # No statement type is required by default
+    result = utils.EndStmtBase.match("CRITICAL", None, "end")
+    assert result == (None, None)
+    # Missing statement type.
+    result = utils.EndStmtBase.match("CRITICAL", None, "end", require_stmt_type=True)
+    assert result is None
+    # Matching statement type.
+    result = utils.EndStmtBase.match(
+        "CRITICAL", None, "end  critical", require_stmt_type=True
+    )
+    assert result == ("CRITICAL", None)
+    # End construct with name but no class to match it with.
+    result = utils.EndStmtBase.match(
+        "SUBROUTINE", None, "end  subroutine sub", require_stmt_type=True
+    )
+    assert result is None
+    # End construct with name that matches with supplied class.
+    result = utils.EndStmtBase.match(
+        "SUBROUTINE",
+        Fortran2003.Subroutine_Name,
+        "end  subroutine sub",
+        require_stmt_type=True,
+    )
+    assert result == ("SUBROUTINE", Fortran2003.Name("sub"))
