@@ -32,21 +32,26 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-''' Test the walk() routine provided by utils.py. '''
+""" Test the walk() routine provided by utils.py. """
 
 import pytest
 from fparser.api import get_reader
 from fparser.two.utils import walk
 from fparser.two import Fortran2003
+from fparser.common.readfortran import FortranStringReader
+from fparser.two.parser import ParserFactory
+from fparser.two.Fortran2003 import Name, Block_Nonlabel_Do_Construct
 
 
 @pytest.mark.usefixtures("f2003_create")
 def test_walk():
-    ''' Test the walk() utility. '''
-    reader = get_reader("program hello\n"
-                        "write(*,*) 'hello'\n"
-                        "write(*,*) 'goodbye'\n"
-                        "end program hello\n")
+    """Test the walk() utility."""
+    reader = get_reader(
+        "program hello\n"
+        "write(*,*) 'hello'\n"
+        "write(*,*) 'goodbye'\n"
+        "end program hello\n"
+    )
     main = Fortran2003.Program(reader)
     # Check that walk produces the same result whether or not the
     # starting node is in a list.
@@ -68,12 +73,14 @@ def test_walk():
 
 @pytest.mark.usefixtures("f2003_create")
 def test_walk_debug(capsys):
-    ''' Test the debug output of the walk() utility. '''
-    reader = get_reader("program just_a_test\n"
-                        "if(.true.)then\n"
-                        "  b = 1\n"
-                        "end if\n"
-                        "end program just_a_test\n")
+    """Test the debug output of the walk() utility."""
+    reader = get_reader(
+        "program just_a_test\n"
+        "if(.true.)then\n"
+        "  b = 1\n"
+        "end if\n"
+        "end program just_a_test\n"
+    )
     main = Fortran2003.Program(reader)
     _ = walk(main, debug=True)
     stdout, _ = capsys.readouterr()
@@ -87,5 +94,33 @@ def test_walk_debug(capsys):
     if_constructs = walk(main, Fortran2003.If_Construct)
     _ = walk(if_constructs[0], indent=4, debug=True)
     stdout, _ = capsys.readouterr()
-    assert stdout.startswith(8*" "+"child type =")
+    assert stdout.startswith(8 * " " + "child type =")
     assert "Program" not in stdout
+
+
+def test_walk_tuples():
+    """Check that the walk utility properly visits tuples.
+    See related issue : https://github.com/stfc/fparser/issues/367
+    and pull request: https://github.com/stfc/fparser/pull/368
+    """
+    source_str = """\
+program test
+    integer :: iterator, size
+    integer, dimension(0:10) :: A, B, C
+    size = 10
+    do iterator = 0,size
+      A(iterator) = B(iterator) * C(iterator)
+    enddo
+end program test
+"""
+    expected = {"A", "B", "C", "iterator", "size"}
+    reader = FortranStringReader(source_str, ignore_comments=True)
+    f_parser = ParserFactory().create(std="f2008")
+    parse_tree = f_parser(reader)
+    doloops = walk(parse_tree, Block_Nonlabel_Do_Construct)
+    assert len(doloops) == 1
+    doloop = doloops[0]
+    allNames = walk(doloop, Name, 0)
+    assert len(allNames) == 8
+    identifierSet = set(map(lambda x: x.tostr(), allNames))
+    assert identifierSet == expected
